@@ -186,9 +186,8 @@ char* oidc_pcre_subst(apr_pool_t *pool, const struct oidc_pcre *pcre, const char
 		const char *rep) {
 	char *rv = NULL;
 #ifdef HAVE_LIBPCRE2
-	PCRE2_SIZE bufsize = (len == 0) ? 16 : 2 * len;
-	PCRE2_UCHAR *output = (PCRE2_UCHAR*) malloc(sizeof(PCRE2_UCHAR) * bufsize);
-	PCRE2_SIZE outlen = bufsize;
+	PCRE2_UCHAR *output = (PCRE2_UCHAR*) malloc(sizeof(PCRE2_UCHAR) * OIDC_PCRE_MAXCAPTURE * 3);
+	PCRE2_SIZE outlen = OIDC_PCRE_MAXCAPTURE * 3;
 	PCRE2_SPTR subject = (PCRE2_SPTR) str;
 	PCRE2_SIZE length = (PCRE2_SIZE) len;
 	PCRE2_SPTR replacement = (PCRE2_SPTR) rep;
@@ -236,6 +235,15 @@ void oidc_pcre_free(struct oidc_pcre *pcre) {
 #endif
 }
 
+void oidc_pcre_free_match(struct oidc_pcre *pcre) {
+#ifdef HAVE_LIBPCRE2
+	if (pcre->match_data) {
+		pcre2_match_data_free(pcre->match_data);
+		pcre->match_data = NULL;
+	}
+#endif
+}
+
 int oidc_pcre_get_substring(apr_pool_t *pool, const struct oidc_pcre *pcre, const char *input,
 		int rc, char **sub_str, char **error_str) {
 	int rv = 0;
