@@ -151,7 +151,8 @@ AP_DECLARE(int) ap_hook_fixups(request_rec *r) {
 	return 0;
 }
 
-AP_DECLARE(void) ap_hook_insert_filter(struct request_rec *r) {
+AP_DECLARE(void) ap_hook_insert_filter(void (*insert_filter)(request_rec *r),
+		const char *const*aszPre, const char *const*aszSucc, int nOrder) {
 }
 
 AP_DECLARE(void) ap_hook_post_config(
@@ -308,6 +309,21 @@ AP_DECLARE(void) ap_log_error_(const char *file, int line, int module_index,
 			return NULL;
 		}
 
+		AP_DECLARE(apr_status_t) ap_mpm_query(int query_code, int *result) {
+			*result = 1;
+			return APR_SUCCESS;
+		}
+
+#if AP_MODULE_MAGIC_AT_LEAST(20080920, 2)
+		AP_DECLARE(apr_status_t) ap_timeout_parameter_parse(
+                                               const char *timeout_parameter,
+                                               apr_interval_time_t *timeout,
+                                               const char *default_time_unit) {
+			*timeout = 0;
+			return APR_SUCCESS;
+		}
+#endif
+
 #if MODULE_MAGIC_NUMBER_MAJOR >= 20100714
 		AP_DECLARE(int) ap_expr_exec(request_rec *r, const ap_expr_info_t *expr,
 				const char **err) {
